NLSL: qrfac.f90 File Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

Functions/Subroutines
qrfac.f90 File Reference

Go to the source code of this file.

## Functions/Subroutines
subroutine | qrfac (m, n, a, lda, pivot, ipvt, lipvt, rdiag, acnorm, wa)

## Function/Subroutine Documentation

subroutine qrfac | ( | integer | m,
|  | integer | n,
|  | double precision, dimension(lda,n) | a,
|  | integer | lda,
|  | logical | pivot,
|  | integer, dimension(n) | ipvt,
|  | integer | lipvt,
|  | double precision, dimension(n) | rdiag,
|  | double precision, dimension(n) | acnorm,
|  | double precision, dimension(n) | wa
| ) |  |

Definition at line 2 of file qrfac.f90.

Here is the caller graph for this function: